<?php
/**
* 2007-2015 PrestaShop
*
* NOTICE OF LICENSE
*
* This source file is subject to the Academic Free License (AFL 3.0)
* that is bundled with this package in the file LICENSE.txt.
* It is also available through the world-wide-web at this URL:
* http://opensource.org/licenses/afl-3.0.php
* If you did not receive a copy of the license and are unable to
* obtain it through the world-wide-web, please send an email
* to license@prestashop.com so we can send you a copy immediately.
*
* DISCLAIMER
*
* Do not edit or add to this file if you wish to upgrade PrestaShop to newer
* versions in the future. If you wish to customize PrestaShop for your
* needs please refer to http://www.prestashop.com for more information.
*
*  @author    PrestaShop SA <contact@prestashop.com>
*  @copyright 2007-2015 PrestaShop SA
*  @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
*  International Registered Trademark & Property of PrestaShop SA
*/

if (!defined('_PS_VERSION_')) {
    exit;
}

class Nowinstore extends Module
{
    protected $config_form = false;

    public function __construct()
    {
        $this->name = 'nowinstore';
        $this->tab = 'advertising_marketing';
        $this->version = '0.13.0';
        $this->author = 'Cedric Fontaine';
        $this->need_instance = 0;
        $this->module_key = '05f2d6ff8f22cacbceb5bd1e000ffb92';

        /**
         * Set $this->bootstrap to true if your module is compliant with bootstrap (PrestaShop 1.6)
         */
        $this->bootstrap = true;

        parent::__construct();

        $this->displayName = $this->l('Now In Store - Automatic Catalog Builder');
        $this->description = $this->l('Easily create catalogs and line sheets within a few minutes with Now In Store.');
    }

    /**
     * Don't forget to create update methods if needed:
     * http://doc.prestashop.com/display/PS16/Enabling+the+Auto-Update
     */
    public function install()
    {
        Configuration::updateValue('NOWINSTORE_LIVE_MODE', false);

        return parent::install();
    }

    public function uninstall()
    {
        Configuration::deleteByName('NOWINSTORE_LIVE_MODE');
        Configuration::deleteByName('NOWINSTORE_API');

        return parent::uninstall();
    }

    /**
     * Load the configuration form
     */
    public function getContent()
    {
        /**
         * If values have been submitted in the form, process.
         */
        $message = null;
        if (((bool)Tools::isSubmit('submitNowinstoreModule')) == true) {
            $message = $this->postProcess();
        }
        
        $this->context->smarty->assign('module_dir', $this->_path);

        if (Configuration::get('NOWINSTORE_LIVE_MODE')==1) {
            $key = Configuration::get('NOWINSTORE_API');
            $url = 'https://www.nowinstore.com/auth/prestashop/callback?shopUrl='
                .urlencode($this->context->shop->getBaseURL()).'&apikey='.$key;
        } else {
            $url='';
        }

        $this->context->smarty->assign('url', $url);
        $this->context->smarty->assign('message', $message);

        $output = $this->context->smarty->fetch($this->local_path.'views/templates/admin/configure.tpl');

        return $output.$this->renderForm();
    }

    /**
     * Create the form that will be displayed in the configuration of your module.
     */
    protected function renderForm()
    {
        $helper = new HelperForm();

        $helper->show_toolbar = false;
        $helper->table = $this->table;
        $helper->module = $this;
        $helper->default_form_language = $this->context->language->id;
        $helper->allow_employee_form_lang = Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG', 0);

        $helper->identifier = $this->identifier;
        $helper->submit_action = 'submitNowinstoreModule';
        $helper->currentIndex = $this->context->link->getAdminLink('AdminModules', false)
            .'&configure='.$this->name.'&tab_module='.$this->tab.'&module_name='.$this->name;
        $helper->token = Tools::getAdminTokenLite('AdminModules');

        $helper->tpl_vars = array(
            'fields_value' => $this->getConfigFormValues(), /* Add values for your inputs */
            'languages' => $this->context->controller->getLanguages(),
            'id_language' => $this->context->language->id,
        );

        return $helper->generateForm(array($this->getConfigForm()));
    }

    /**
     * Create the structure of your form.
     */
    protected function getConfigForm()
    {
        return array(
            'form' => array(
                'legend' => array(
                'title' => $this->l('Settings'),
                'icon' => 'icon-cogs',
                ),
                'input' => array(
                    array(
                        'type' => 'switch',
                        'label' => $this->l('Live mode'),
                        'name' => 'NOWINSTORE_LIVE_MODE',
                        'is_bool' => true,
                        'desc' => $this->l('Use this module in live mode'),
                        'values' => array(
                            array(
                                'id' => 'active_on',
                                'value' => 1,
                                'label' => $this->l('Enabled')
                            ),
                            array(
                                'id' => 'active_off',
                                'value' => 0,
                                'label' => $this->l('Disabled')
                            )
                        ),
                    ),
                ),
                'submit' => array(
                    'title' => $this->l('Save'),
                ),
            ),
        );
    }

    /**
     * Set values for the inputs.
     */
    protected function getConfigFormValues()
    {
        return array(
            'NOWINSTORE_LIVE_MODE' => Configuration::get('NOWINSTORE_LIVE_MODE', 0),
            'NOWINSTORE_API' => Configuration::get('NOWINSTORE_API', ''),
        );
    }

    /**
     * Save form data.
     */
    protected function postProcess()
    {
        Configuration::updateValue('NOWINSTORE_LIVE_MODE', Tools::getValue('NOWINSTORE_LIVE_MODE'));

        if (Configuration::get('NOWINSTORE_LIVE_MODE')==1) {
            if (Configuration::get('NOWINSTORE_API') == '') {
                $key = Tools::strtoupper(Tools::passwdGen(32, 'ALPHANUMERIC'));

                // On active le Webservice
                Configuration::updateValue('PS_WEBSERVICE', true);
                Configuration::updateValue('NOWINSTORE_API', $key);
                
                
                Db::getInstance()->insert('webservice_account', array(
                    'key'           => pSQL($key),
                    'description'   => 'Now in Store Module',
                    'active'        => 1
                ));
                
                $context = Context::getContext();
                $account_id = Db::getInstance()->Insert_ID();
                Db::getInstance()->insert('webservice_account_shop', array(
                    'id_webservice_account'     => $account_id,
                    'id_shop'                   => $context->shop->id
                ));
                
                Tools::generateHtaccess();
                WebserviceKey::setPermissionForAccount($account_id, array('products'=>array('GET'=>1)
                                                                        ,'categories'=>array('GET'=>1)
                                                                        ,'images'=>array('GET'=>1)
                                                                        ,'contacts'=>array('GET'=>1)
                                                                        ,'currencies'=>array('GET'=>1)
                                                                        ,'shops'=>array('GET'=>1)
                                                                        ,'stores'=>array('GET'=>1)));
            }
            $message = $this->displayConfirmation($this->l('The Now In Store module was successfully activated.'));
        } else {
            Configuration::updateValue('NOWINSTORE_API', '');
            $message = $this->displayWarning($this->l('The Now In Store module was deactivated.'));
        }
        return $message;
    }
}
